@@ -1,5 +1,5 @@
 package Bot::Cobalt::IRC::Event::Mode;
-$Bot::Cobalt::IRC::Event::Mode::VERSION = '0.017007';
+$Bot::Cobalt::IRC::Event::Mode::VERSION = '0.017008';
 use strictures 2;
 
 use Bot::Cobalt;
@@ -30,8 +30,7 @@ has is_umode => (
     my ($self)  = @_;
     my $casemap = core->get_irc_casemap( $self->context );
     my $irc_obj = core->get_irc_object( $self->context );
-    my $me = $irc_obj->nick_name;
-    eq_irc($me, $self->target) ? 1 : 0
+    eq_irc($irc_obj->nick_name, $self->target)
   },
 );
 
