@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::RDB::Database;
-$Bot::Cobalt::Plugin::RDB::Database::VERSION = '0.017007';
+$Bot::Cobalt::Plugin::RDB::Database::VERSION = '0.017008';
 ## Frontend to managing RDB-style Bot::Cobalt::DB instances
 ## I regret writing this.
 ##
@@ -482,7 +482,7 @@ sub _gen_unique_key {
   $newkey .= $v[rand @v] while exists $db->Tied->{$newkey};
 
   ## regen 0000 keys:
-  return $newkey || $self->_gen_unique_key
+  $newkey =~ /^0+$/ ? $self->_gen_unique_key : $newkey
 }
 
 sub _rdb_switch {
